$AssetsImagesGen class
Constructors
- $AssetsImagesGen()
-
const
Properties
- bgButton2 → AssetGenImage
-
File path: assets/images/bg_button2.webp
no setter
- bgButton3 → AssetGenImage
-
File path: assets/images/bg_button3.webp
no setter
- bgTemplate1 → AssetGenImage
-
File path: assets/images/bg_template1.webp
no setter
- bgTemplate2 → AssetGenImage
-
File path: assets/images/bg_template2.webp
no setter
- bgTemplate3 → AssetGenImage
-
File path: assets/images/bg_template3.webp
no setter
- bgTemplate4 → AssetGenImage
-
File path: assets/images/bg_template4.webp
no setter
- bgTemplate5 → AssetGenImage
-
File path: assets/images/bg_template5.webp
no setter
- bgTemplate6 → AssetGenImage
-
File path: assets/images/bg_template6.webp
no setter
- diamond → AssetGenImage
-
File path: assets/images/diamond.webp
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- leftLeaf → AssetGenImage
-
File path: assets/images/left_leaf.webp
no setter
- rightLeaf → AssetGenImage
-
File path: assets/images/right_leaf.webp
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stars → AssetGenImage
-
File path: assets/images/stars.webp
no setter
-
values
→ List<
AssetGenImage> -
List of all assets
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited