$AssetsSvgGen class
Constructors
- $AssetsSvgGen()
-
const
Properties
- appStore → SvgGenImage
-
File path: assets/svg/app_store.svg
no setter
- check5 → SvgGenImage
-
File path: assets/svg/check5.svg
no setter
- close → SvgGenImage
-
File path: assets/svg/close.svg
no setter
- googlePlay → SvgGenImage
-
File path: assets/svg/google_play.svg
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ List<
SvgGenImage> -
List of all assets
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited